% Example script calling the liebe_gas function
% Calculates the gas attenuation from 1-1000 GHz
% for a saturated (RH=100%) and dry (RH=1%) atmosphere
% at a fixed temperature and pressure

TC=25; % Temperature in degrees C
p_hPa=1000; % pressure in hPa

frequencies=1:1:1000; % GHz
dB_attenuation_saturated=frequencies; dB_attenuation_dry=frequencies; % set up array for results

load L_oxygen_data; % produces data table M
load L_vapour_data; % produced data table M2

for jf=1:length(frequencies)
   f=frequencies(jf);
   
   rh=100; % Relative Humidity in percent
   [Nl,att]=liebe_gas(f,TC,rh,p_hPa,M,M2);
   dB_attenuation_saturated(jf)=att; % dB/km
   
   rh=1; % Relative Humidity in percent
   [Nl,att]=liebe_gas(f,TC,rh,p_hPa,M,M2);
   dB_attenuation_dry(jf)=att; % dB/km
   
end
figure; 
semilogy(frequencies,dB_attenuation_dry,'k'); grid on;
hold on
plot(frequencies,dB_attenuation_saturated,'b'); grid on;
ylabel('Attenuation [dB/km]')
xlabel('Frequency [GHz]')
legend('1% RH','100% RH')
title(['T [C] = ' num2str(TC) ' , p [hPa] = ' num2str(p_hPa)])

% Can use the plot below to show the Imaginary part of N vs frequency as a
% sanity check to show that matches results in Figure 1 of Liebe et al 1989 
% figure; 
% semilogy(frequencies,dB_attenuation_dry./(0.182*frequencies),'k'); grid on;
% hold on
% plot(frequencies,dB_attenuation_saturated./(0.182*frequencies),'b'); grid on;
% ylabel('Imag{N}')
% xlabel('Frequency [GHz]')
% legend('1% RH','100% RH')
% title(['T [C] = ' num2str(TC) ' , p [hPa] = ' num2str(p_hPa)])
